@@ -16,7 +16,7 @@ parser.add_argument(
     "-r", "--rewrite", help="rewrite text file path (default: ./rewrite.def)"
 )
 parser.add_argument("--ignore", action='store_true',
-                    help="ignore unsupported pos error")
+                    help="ignore invalid format line or unsupported pos error")
 
 pos_dict = {
     "固有名詞": "名詞,固有名詞,一般,*,*,*",
@@ -38,6 +38,10 @@ class UnSupportedPosError(Error):
     pass
 
 
+class DictFormatError(Error):
+    pass
+
+
 def nomlized_yomi(yomi: str) -> str:
     yomi = jaconv.hira2kata(yomi)
     if p.fullmatch(yomi):
@@ -57,10 +61,13 @@ def pos_convert(pos: str) -> str:
 
 def convert(line: str, rewrite="rewrite.def") -> str:
     data = line.split(",")
-    word = data[0]
-    # splited = data[1]
-    yomi = nomlized_yomi(data[2])
-    pos = pos_convert(data[3])
+    try:
+        word = data[0]
+        # splited = data[1]
+        yomi = nomlized_yomi(data[2])
+        pos = pos_convert(data[3])
+    except IndexError:
+        raise DictFormatError(f"{line} is invalid format")
 
     normalizer = SudachiCharNormalizer(rewrite_def_path=rewrite)
     normalized = normalizer.rewrite(word)
@@ -79,7 +86,7 @@ def cli() -> str:
             converted = ""
             try:
                 converted = convert(line, rewrite)
-            except UnSupportedPosError as e:
+            except (UnSupportedPosError, DictFormatError) as e:
                 if args.ignore:
                     continue
                 else:
